@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,10 +11,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""System error indicator
-
-$Id: systemerror.py 100078 2009-05-18 17:08:59Z icemac $
-"""
+"""System error indicator"""
 
 import zope.interface
 import zope.browser.interfaces
